import 'package:flutter/material.dart';
import '../../../../widget/confirmDialog.dart';
import 'models/abiturCalculatorModel.dart';
import 'models/subject.dart';
import 'package:provider/provider.dart';

class AbiturCalculatorView extends StatelessWidget {
  const AbiturCalculatorView({super.key});

  static RichText listSubjects(List<Subject> subjects) {
    return RichText(
      textAlign: TextAlign.center,
      text: TextSpan(
        children: subjects.map((subject) {
          return List<InlineSpan>.from([
            WidgetSpan(child: Icon(subject.icon, size: 15)),
            const WidgetSpan(child: SizedBox(width: 3)),
            TextSpan(text: subject.displayName),
            if(subjects.last != subject) const WidgetSpan(child: SizedBox(width: 10)),
          ]);
        }).expand((e) => e).toList(),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<AbiturCalculatorModel>(builder: (context, state, child) {
      return Scaffold(
          appBar: AppBar(
            title: const Text('Abitur Notenrechner'),
            actions: [
              IconButton(
                onPressed: () => ConfirmDialog(
                  title: 'Zurücksetzen',
                  content: 'Alle Felder werden zurückgesetzt',
                  confirmButton: 'Löschen',
                  onConfirm: state.reset,
                ).asDialog(context),
                icon: const Icon(Icons.delete_outline_outlined),
              )
            ],
          ),
          body: Stepper(
            type: StepperType.vertical,
            steps: state.getSteps,
            currentStep: state.getCurrentStepIndex,

            onStepContinue: () => state.increaseStep(),
            onStepCancel: () => state.decreaseStep(),

            stepIconBuilder: (stepIndex, stepState) => _stepIconBuilder(context, stepIndex, stepState),
            controlsBuilder: _controlsBuilder,
          )
      );
    });
  }

  Widget _stepIconBuilder(BuildContext context, int stepIndex, StepState stepState) {
    return Consumer<AbiturCalculatorModel>(builder: (context, state, child) {
      return Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(20),
          color: state.getCurrentStepIndex == stepIndex
              ? Theme.of(context).primaryColor
              : Theme.of(context).colorScheme.surfaceVariant,
        ),
        child: Center(
          child: Text((++stepIndex).toString()),
        ),
      );
    });
  }

  Widget _controlsBuilder(BuildContext context, ControlsDetails details) {
    return Row(
      children: [
        TextButton(
          onPressed: details.onStepCancel,
          child: const Text('Zurück'),
        ),
        TextButton(
          onPressed: details.onStepContinue,
          child: const Text('Weiter'),
        ),
      ]
    );
  }
}