import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../abiturCalculatorStep.dart';
import '../steps/resultStep.dart';
import '../steps/selectGkStep.dart';
import '../steps/selectLkStep.dart';
import '../steps/selectPfStep.dart';
import '../steps/welcomeStep.dart';
import 'subject.dart';

class AbiturCalculatorModel extends ChangeNotifier {
  static final SubjectCollection _collection = SubjectCollection([
    Subject(displayName: 'Deutsch', icon: Icons.translate_outlined, canBeLk: true, importantLk: true),
    Subject(displayName: 'Erste Fremdsprache', icon: Icons.translate_outlined, canBeLk: true, importantLk: true),
    Subject(displayName: 'Zweite Fremdsprache', icon: Icons.translate_outlined, canBeLk: true, importantLk: true),
    Subject(displayName: 'Zweite Fremdsprache ab Kl. 11', icon: Icons.translate_outlined, canBeLk: false, importantLk: false),
    Subject(displayName: 'Kunst', icon: Icons.brush_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Musik', icon: Icons.music_note_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Darstellendes Spiel', icon: Icons.theater_comedy_outlined, canBeLk: false, importantLk: false),
    Subject(displayName: 'PoWi', icon: Icons.book_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Geschichte', icon: Icons.history_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Religion', icon: Icons.church_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Erdkunde', icon: Icons.map_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Mathematik', icon: Icons.calculate_outlined, canBeLk: true, importantLk: true),
    Subject(displayName: 'Chemie', icon: Icons.science_outlined, canBeLk: true, importantLk: true),
    Subject(displayName: 'Physik', icon: Icons.add, canBeLk: true, importantLk: true),
    Subject(displayName: 'Biologie', icon: Icons.add, canBeLk: true, importantLk: true),
    Subject(displayName: 'Biochemie', icon: Icons.biotech_outlined, canBeLk: false, importantLk: false),
    Subject(displayName: 'Informatik', icon: Icons.code_outlined, canBeLk: true, importantLk: false),
    Subject(displayName: 'Sport', icon: Icons.sports_basketball_outlined, canBeLk: true, importantLk: false),
  ]);

  static final List<AbiturCalculatorStep> _steps = [
    const WelcomeStep(),
    SelectLkStep(),
    SelectGkStep(),
    const SelectPfStep(),
    const ResultStep(),
  ];
  
  List<AbiturCalculatorStep> get getSteps => _steps;
  AbiturCalculatorStep getCurrentStep() => _steps[getCurrentStepIndex];

  static AbiturCalculatorModel get(BuildContext context) {
    return Provider.of<AbiturCalculatorModel>(context, listen: false);
  }

  int _currentStep = 0;

  SubjectCollection getSubjects({bool update = false}) {
    if(update) notifyListeners();
    return _collection;
  }

  void update() {
    notifyListeners();
  }

  int get getCurrentStepIndex => _currentStep;
  void increaseStep() {
    if(getCurrentStep().canGoNextStep(getSubjects())) _currentStep++;
    notifyListeners();
  }
  void decreaseStep() {
    if(_currentStep >= 1) _currentStep--;
    notifyListeners();
  }

  void reset() {
    _currentStep = 0;
    for (var e in _collection.collection) {
      e.reset();
    }
    notifyListeners();
  }

  AbiturCalculatorModel() {
    reset();
  }
}