import 'package:flutter/material.dart';
import '../../../../../widget/providerBridge.dart';

import '../../../../../widget/centeredLeading.dart';
import '../abiturCalculatorStep.dart';
import '../abiturCalculatorView.dart';
import '../models/abiturCalculatorModel.dart';
import '../models/subject.dart';

class SelectLkStep extends AbiturCalculatorStep {
  SelectLkStep() : super(
    title: const Text('Leistungskurse'),
    content: StatefulBuilder(builder: (context, setState) {
      var model = AbiturCalculatorModel.get(context);
      var lkSubjects = model.getSubjects().collection.where((e) => e.isLk()).toList();
      return Column(
        children: [
          AbiturCalculatorView.listSubjects(lkSubjects),
          TextButton(
            onPressed: () {
              ProviderBridge.toDialog(context, model, (context, value) {
                return AlertDialog(
                  title: const Text('Leistungskurse'),
                  content: SingleChildScrollView(
                    child: Column(
                      mainAxisSize: MainAxisSize.min,
                      children: model.getSubjects().collection.map((e) {
                        return ListTile(
                          leading: CenteredLeading(Icon(e.icon)),
                          title: Text(e.displayName),
                          trailing: Checkbox(
                            value: e.isLk(),
                            onChanged: e.isLk() || e.canLk(model.getSubjects().collection) ? (value) {
                              e.unsafeLkToggle = value!;
                              model.update();
                            } : null,
                          ),
                        );
                      }).toList(),
                    ),
                  ),
                  actions: [
                    TextButton(
                      onPressed: () {
                        Navigator.of(context).pop();
                      },
                      child: const Text('Fertig'),
                    )
                  ],
                );
              });
            },
            child: Text("Leistungskurse ${lkSubjects.isEmpty ? "auswählen" : "ändern"}"),
          ),
        ],
      );
    }),
  );

  @override
  bool canGoNextStep(SubjectCollection subjects) {
    return subjects.collection.where((element) => element.isLk()).length >= 2;
  }
}
class SelectLkStepTest extends StatelessWidget {
  const SelectLkStepTest({super.key});

  @override
  Widget build(BuildContext context) {
    return const Placeholder();
  }
}
